==> unity-controls-ums-0.0.3.tgz: package/src/App.tsx <==
import React from 'react'
import { Box, unityTheme } from '@ntpkunity/controls'
import './App.css'
import TenantProfileComponent from './modules/authentication/components/tenantProfile/tenantProfileComponent'
// import LoginComponent from './modules/authentication/components/login/loginComponent'
// import ForgotPasswordComponent from './modules/authentication/components/forgotPassword/forgotPasswordComponent'
// import ResetPasswordComponent from './modules/authentication/components/resetPassword/resetPasswordComponent'
// import { SignupComponent } from './modules/authentication/components/signup/signupComponent'
//import UserProfileComponent from './modules/authentication/components/userProfile/userProfileComponent'
// import TermsCondAgreementComponent from './modules/authentication/components/termsCondAgreement/termsCondAgreementComponent'
// import { ResetPasswordLinkComponent } from './modules'
// import { EmailVerificationLinkComponent } from './modules/authentication/authenticationModule'

const App: React.FC = () => {
  const [response, setResponse] = React.useState<any>(undefined)

  React.useEffect(() => {
    console.log(response, 'change in response')
  }, [response])

  return (
    <Box theme={unityTheme} className="demo-container">
      {/* <LoginComponent app={'Appex Now'} setResponse={setResponse} /> */}
      {/*  <ForgotPasswordComponent
                setResponse={setResponse}
                nextScreenUrl={'http://localhost:3000/'}
                theme={unityTheme}
                heading = 'Forgot Password?'
                label = 'Enter Your Registered Email Address'
                buttonText = 'Send Reset Link'
                message = 'Please enter your registered email address for security purposes. When you receive the reset password email, please follow the instructions.'
                onChange={(e: any) => {
                  console.log('change val', e)
                }}
      />
      <ResetPasswordComponent
        setResponse={setResponse}
        nextScreenUrl={'http://localhost:3000/'}
        theme={unityTheme}
        userId = {16}
        validateUrl={'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJ1c2VyX2lkIjoxNiwiZW1haWwiOiJrYXNoaWZheXlhekB5YWhvby5jb20iLCJrZXkiOiJyY2R6Z2NxdSJ9.0F4z5sSuUN1FVsa0Idb60JGANej8EN3ak8MclNbgsqU'}
        heading = 'Reset Your Password'
        />
      {/* <SignupComponent verificationScreenUrl={'http://localhost:3000/'} setResponse={setResponse} /> */}
      {/* <UserProfileComponent validateUrl={'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJ1c2VyX2lkIjoxMSwiZW1haWwiOiJ0YWxoYW1vYmluMzEzQGdtYWlsLmNvbSIsImtleSI6InZhaG92cGJlIn0.AwvSYp6Al9NG1mOASxLbDh-Cn9CODJQgjTOrUrs7kII'} setResponse={setResponse} /> */}
      <TenantProfileComponent
        setResponse={setResponse}
        email={'email2@gmail.com'}
      />
      {/* <TermsCondAgreementComponent /> */}
      {/* <ResetPasswordLinkComponent />  */}
      {/* <EmailVerificationLinkComponent /> */}
    </Box>
  )
}

export default App

==> unity-controls-ums-0.0.11.tgz: package/src/App.tsx <==
import React from 'react'
import { Box, unityTheme } from '@ntpkunity/controls'
import './App.css'
// import LoginComponent from './modules/authentication/components/login/loginComponent'
// import TenantProfileComponent from './modules/authentication/components/tenantProfile/tenantProfileComponent'
// import ForgotPasswordComponent from './modules/authentication/components/forgotPassword/forgotPasswordComponent'
// import LoginComponent from './modules/authentication/components/login/loginComponent'
// import ResetPasswordComponent from './modules/authentication/components/resetPassword/resetPasswordComponent'
import { SignupComponent } from './modules/authentication/components/signup/signupComponent'
// import UserProfileComponent from './modules/authentication/components/userProfile/userProfileComponent'
// import TermsCondAgreementComponent from './modules/authentication/components/termsCondAgreement/termsCondAgreementComponent'
// import { ResetPasswordLinkComponent } from './modules'
// import { EmailVerificationLinkComponent } from './modules/authentication/authenticationModule'

const App: React.FC = () => {
  const [response, setResponse] = React.useState<any>(undefined)

  React.useEffect(() => {
    console.log(response, 'change in response')
  }, [response])

  return (
    <Box theme={unityTheme} className="demo-container">
      {/* <LoginComponent app={'Appex Now'} setResponse={setResponse} /> */}

      {/*  <ForgotPasswordComponent

                setResponse={setResponse}
                nextScreenUrl={'http://localhost:3000/'}
                theme={unityTheme}
                heading = 'Forgot Password?'
                label = 'Enter Your Registered Email Address'
                buttonText = 'Send Reset Link'
                message = 'Please enter your registered email address for security purposes. When you receive the reset password email, please follow the instructions.'
                onChange={(e: any) => {
                  console.log('change val', e)
                }}
      /> */}

      {/* <ResetPasswordComponent
        setResponse={setResponse}
        nextScreenUrl={'http://localhost:3000/'}
        theme={unityTheme}
        userId = {16}
        validateUrl={'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJ1c2VyX2lkIjoxNiwiZW1haWwiOiJrYXNoaWZheXlhekB5YWhvby5jb20iLCJrZXkiOiJyY2R6Z2NxdSJ9.0F4z5sSuUN1FVsa0Idb60JGANej8EN3ak8MclNbgsqU'}
        heading = 'Reset Your Password'
        /> */}

      <SignupComponent verificationScreenUrl={'http://localhost:3000/'} setResponse={setResponse} />

      {/* <UserProfileComponent
      validateUrl={'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJ1c2VyX2lkIjozLCJlbWFpbCI6InRhbGhhLm1vYmluQG5ldHNvbHRlY2guY29tIiwia2V5IjoibmFod2l2enEifQ.x6OlSZCOuy_z9TMGy6keX7knaIN9XX2hIMqvBSkkWd0'}
      setResponse={setResponse} /> */}

      {/* <TenantProfileComponent
        setResponse={setResponse}
        email={'email2@gmail.com'}
      />
      {/* <TermsCondAgreementComponent /> */}

      {/* <ResetPasswordLinkComponent />  */}

      {/* <EmailVerificationLinkComponent
        email={'talha.mobin@netsoltech.com'}
        verificationScreenUrl={'http://localhost:3000/'}
        setResponse={setResponse}
      /> */}

    </Box>
  )
}

export default App
